==> open-xchange-file-storage-dropbox_7.8.1.orig.tar.bz2: open-xchange-file-storage-dropbox-7.8.1/com.openexchange.file.storage.dropbox/src/com/openexchange/file/storage/dropbox/DropboxConstants.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.file.storage.dropbox;

import com.openexchange.file.storage.FileStorageConstants;

/**
 * {@link DropboxConstants} - Provides useful constants for Dropbox file storage.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class DropboxConstants implements FileStorageConstants {

    /**
     * The identifier for Dropbox file storage service.
     */
    public static final String ID = "dropbox";

    /**
     * The configuration property name for Dropbox API key.
     */
    public static final String API_KEY = "apiKey";

    /**
     * The configuration property name for Dropbox secret key.
     */
    public static final String SECRET_KEY = "secretKey";

    /**
     * The default API key.
     */
    public static final String KEY_API = "no-default-available";

    /**
     * The default secret key.
     */
    public static final String KEY_SECRET = "no-default-available";

    /**
     * Initializes a new {@link DropboxConstants}.
     */
    private DropboxConstants() {
        super();
    }

}

==> open-xchange-file-storage-dropbox_7.10.3.orig.tar.bz2: open-xchange-file-storage-dropbox-7.10.3/com.openexchange.file.storage.dropbox/src/com/openexchange/file/storage/dropbox/DropboxConstants.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.file.storage.dropbox;

import com.openexchange.file.storage.FileStorageConstants;

/**
 * {@link DropboxConstants} - Provides useful constants for Dropbox file storage.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public final class DropboxConstants implements FileStorageConstants {

    /**
     * The identifier for Dropbox file storage service.
     */
    public static final String ID = "dropbox";
    
    /**
     * The display name for dropbox file storage service.
     */
    public static final String DISPLAY_NAME = "Dropbox File Storage Service";

    /**
     * The configuration property name for Dropbox API key.
     */
    public static final String API_KEY = "apiKey";

    /**
     * The configuration property name for Dropbox secret key.
     */
    public static final String SECRET_KEY = "secretKey";

    /**
     * The configuration property name for Dropbox product name.
     */
    public static final String PRODUCT_NAME = "productName";

    /**
     * The default API key.
     */
    public static final String KEY_API = "no-default-available";

    /**
     * The default secret key.
     */
    public static final String KEY_SECRET = "no-default-available";

    /**
     * Initializes a new {@link DropboxConstants}.
     */
    private DropboxConstants() {
        super();
    }

}
